@@ -41,11 +41,16 @@ sub init_human_text{
 	['apache',_('Web Server'),'apache'],
 	['apache2',_('New generation Web Server'),'apache2'],
 	['apmd',_('Monitors battery status for some older laptops'),'apmd'],
+	['apport',_('Tool to report program crashes'),0],
 	['atd',_('Enables scheduling of jobs'),'atd'],
 	['autofs',_('Automounter for Linux'),'autofs'],
+	['avahi-daemon', _('Discover services and hosts on a local network'),'avahi-daemon'],
 	['binfmt-support',_('Support for extra formats to run programs'),0],
 	['bind9', _('Service to get internet domain names'),'named'],
+	['bittorrent',_('Easy scatter-gather network file transfer'),'bttrack.bittorr'],
+	['bootclean', _('Scripts for initializing and shutting down the system'),0],
 	['bootlogd',_('Saves messages at boot to a log file'),'bootlogd'],
+	['bluetooth',,_('Bluetooth services'),'hcid'],
 	['bluez-utils',_('Bluetooth services'),'hcid'],
 	['clamav-freshclam',_('Update virus database'),'freshclam'],
 	['cron',_('Runs system housekeeping chores on specified dates/times'),'cron'],
@@ -59,6 +64,7 @@ sub init_human_text{
 	['evms',_('Hard Disk Volume Management'),0],
 	['fam',_('Detects changes in files/directories'),'famd'],
 	['fetchmail',_('Mail retrieval and forwarding utility'),'fetchmail'],
+	['festival',_('A Text to Speech synthesis software'),'festival'],
 	['fnfxd',_('Power and special key management for Toshiba laptops'),'fnfxd'],
 	['gdm',_('GNOME Display Manager'),'gdm'],
 	['hdparm',_('Tunes hard disk parameters for high performance'),0],
@@ -79,6 +85,7 @@ sub init_human_text{
 	['mpd',_('Allows remote access for playing music'),'mpd'],
 	['mysql',_('Fast and stable SQL database server'),'mysqld'],
 	['networking',_('Manages your Internet connection'),0],
+	['ntp',_('Update the system time using the Internet'),'ntpd'],
 	['ntpdate',_('Update the system time using the Internet'),0],
 	['nvidia-glx',_('NVIDIA video card management'),0],
 	['nvidia-kernel',_('Common files for NVIDIA video cards'),0],
