@@ -19,7 +19,6 @@
 #    Free Software Foundation, Inc.,                                       #
 #    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
 #
-# Parts of code dervied from rcconf  Copyright (c) 1999-2004 kamop@debian.org
 # 
 ############################################################################
 
@@ -281,15 +280,18 @@ sub get_cache_info
 
 	if ($pkg ne "") {
        		$s_info = `apt-cache show $pkg`; #dpkg --print-avail
-       		my $start = rindex($s_info,"Description:");
+       		my $start = rindex($s_info,"Description");
        		my $end = rindex($s_info,"Bugs");
 		if ($start >= $end) {$end = $start-1;}
 		$s_info=substr($s_info,$start,$end-$start);
+       		$start = index($s_info,":");
+       		if ($start > -1 ) {
+       			$s_info = substr $s_info,$start+1;
+       			}
        
-		my @descr =  grep (/^Description:/,split(/\n/,$s_info));
-        	$descr = join(' ',@descr);
-		$descr=~ s/Description: //;
-        	$s_info =~ s/(Description:).*//g;
+		$end = index($s_info,"\n");
+		$descr = substr($s_info,0,$end);
+		$s_info = substr($s_info, $end+1);
         }
 
 	if ($s_info eq "" ) { 
@@ -747,8 +749,7 @@ sub select_default{
     $stop_num = $link->[11];
 	$stop_num = $link->[10] if ($stop_num eq '-01'); #if there is no K in RL1, get the one in RL0
 
-	#rule S link in 2-3-4-5 AND S/K link in 1, AND K link in 0-6
-	
+	#rule 1: S link in 2-3-4-5 AND S/K link in 1, AND K link in 0-6 (update-rc.d defaults)	
     if ( ( $start_num ne '-01' )   &&
          (($link->[1] ne '-01')  || ($link->[11] ne '-01')) &&
          ( $link->[3] ne '-01' ) &&
@@ -757,12 +758,26 @@ sub select_default{
 	 ($link->[10] ne '-01') &&
          ($link->[16] ne '-01') 
          ) {   
-      push(@select, $package);
-     
-        		$data->{$package}->{'start'} = $start_num;
-        		$data->{$package}->{'stop'} = $stop_num;
-    }
-  } ## foreach
+      		push(@select, $package);
+        	$data->{$package}->{'start'} = $start_num;
+        	$data->{$package}->{'stop'} = $stop_num;
+        	next;
+    		}
+
+	#rule 2: S link in 2-3-4-5 AND K link in 1 (update-rc.d multiuser)    		
+    if ( ( $start_num ne '-01' )   &&
+         (($link->[1] ne '-01')  || ($link->[11] ne '-01')) &&
+         ( $link->[3] ne '-01' ) &&
+         ( $link->[4] ne '-01') &&
+         ( $link->[5] ne '-01' )
+         ) {   
+      		push(@select, $package);
+        	$data->{$package}->{'start'} = $start_num;
+        	$data->{$package}->{'stop'} = $stop_num;
+    		}
+    		
+    	
+  	} ## foreach
  
   return \@select;
 } ## select_default()
